@@ -27,7 +27,7 @@
 #include <gtk/gtk.h>
 #include "dlg-package-installer.h"
 #include "gtk-utils.h"
-#include "main.h"
+#include "fr-init.h"
 
 
 typedef struct {
@@ -60,7 +60,7 @@ package_installer_terminated (InstallerData   *idata,
 
 	if (error_type != FR_PROC_ERROR_NONE) {
 		fr_archive_action_completed (idata->archive,
-					     FR_ACTION_CREATING_NEW_ARCHIVE,
+					     idata->action,
 					     error_type,
 					     error_message);
 	}
@@ -169,7 +169,11 @@ install_packages (InstallerData *idata)
 
 			cursor = gdk_cursor_new (GDK_WATCH);
 			gdk_window_set_cursor (window, cursor);
+#if GTK_CHECK_VERSION (3, 0, 0)
+			g_object_unref (cursor);
+#else
 			gdk_cursor_unref (cursor);
+#endif
 		}
 
 		proxy = g_dbus_proxy_new_sync (connection,
