@@ -331,6 +331,7 @@ fr_command_tar_add (FrCommand     *comm,
 	if (! recursive)
 		fr_process_add_arg (comm->process, "--no-recursion");
 	fr_process_add_arg (comm->process, "--no-wildcards");
+	fr_process_add_arg (comm->process, "--no-unquote");
 	fr_process_add_arg (comm->process, "-v");
 	fr_process_add_arg (comm->process, "-p");
 
@@ -401,6 +402,7 @@ fr_command_tar_delete (FrCommand  *comm,
 	fr_process_set_begin_func (comm->process, begin_func__delete, comm);
 	fr_process_add_arg (comm->process, "--force-local");
 	fr_process_add_arg (comm->process, "--no-wildcards");
+	fr_process_add_arg (comm->process, "--no-unquote");
 	fr_process_add_arg (comm->process, "-v");
 	fr_process_add_arg (comm->process, "--delete");
 	fr_process_add_arg (comm->process, "-f");
@@ -448,6 +450,7 @@ fr_command_tar_extract (FrCommand  *comm,
 	begin_tar_command (comm);
 	fr_process_add_arg (comm->process, "--force-local");
 	fr_process_add_arg (comm->process, "--no-wildcards");
+	fr_process_add_arg (comm->process, "--no-unquote");
 	fr_process_add_arg (comm->process, "-v");
 	fr_process_add_arg (comm->process, "-p");
 
@@ -795,9 +798,13 @@ get_uncompressed_name (FrCommandTar *c_tar,
 			new_name[l - 5] = 0;
 	}
 	else if (is_mime_type (comm->mime_type, "application/x-xz-compressed-tar")) {
-		/* X.tar.xz --> X.tar
-		 * (There doesn't seem to be a shorthand suffix) */
-		if (file_extension_is (e_filename, ".tar.xz"))
+		/* X.txz     -->  X.tar
+		 * X.tar.xz  -->  X.tar */
+		if (file_extension_is (e_filename, ".txz")) {
+			new_name[l - 2] = 'a';
+			new_name[l - 1] = 'r';
+		}
+		else if (file_extension_is (e_filename, ".tar.xz"))
 			new_name[l - 3] = 0;
 	}
 	else if (is_mime_type (comm->mime_type, "application/x-lzop-compressed-tar")) {
